import httpRequest from '@/utils/axios'
/**
 * 操作日志
 */
export function operateLog(params) {
  const logMsg = `操作人：${params.user.nickname}，操作：${params.type}`
  const data = {
    detail: logMsg
  }
  httpRequest.post('/api/live/admin/v2/system/log/write', data).then(res => {
    console.log(res)
  }).catch(() => {})
}
/**
 * 模糊搜索
 */
export function searchUserList(params) {
  return httpRequest.get('/api/live/common/v1/sso-user/search', { params })
}

/* ----------------------------系统用户管理---------------------------- */
/**
 * 获取当前用户的角色
 */
export function getUserRoles() {
  return httpRequest.get('/api/live/admin/v2/user/roles')
}
/**
 * 创建角色
 */
export function createRole(data) {
  return httpRequest.post('/api/live/admin/v2/role', data)
}
/**
 * 更新角色
 */
export function updateRole(id, params) {
  return httpRequest.put(`/api/live/admin/v2/role/${id}/update`, params)
}
/**
 * 获取角色详情
 */
export function getRoleDetails(params) {
  return httpRequest.get(`/api/live/admin/v2/role/${params.role_id}/detail`, { params })
}
/**
 * 删除
 */
export function deleteRole(id) {
  return httpRequest.delete(`/api/live/admin/v2/role/${id}/delete`)
}
/**
 * 获取角色列表
 */
export function getRoles(params) {
  return httpRequest.get('/api/live/admin/v2/roles', { params })
}
/**
 * 分配角色给用户
 */
export function roleToUser(data) {
  return httpRequest.post('/api/live/admin/v2/assign/roles-to-user', data)
}
/**
 * 获取角色下的用户列表
 */
export function getUserListUnderRole(params) {
  return httpRequest.get(`/api/live/admin/v2/role/${params.role_id}/users`, { params })
}
/**
 * 从角色中移除用户
 */
export function romoveUserUnderRole(data) {
  return httpRequest.post('/api/live/admin/v2/assign/remove-user-form-role', data)
}
/**
 * 获取权限列表
 */
export function getPermissions(params) {
  return httpRequest.get('/api/live/admin/v2/permissions', { params })
}
/**
 * 分配权限给角色
 */
export function permissionToRole(data) {
  return httpRequest.post('/api/live/admin/v2/assign/permission-to-role', data)
}

/* ----------------------------系统用户管理---------------------------- */
/**
 * 创建系统用户
 */
export function createAccount(data) {
  return httpRequest.post('/api/live/admin/v2/user/create', data)
}
/**
 * 删除系统用户
 */
export function deleteAccount(data) {
  return httpRequest.post('/api/live/admin/v2/user/batch-delete', data)
}
/**
 * 获取系统用户列表(分页)
 */
export function getAccountList(params) {
  return httpRequest.get('/api/live/admin/v2/users', { params })
}
